@@ -1,11 +1,10 @@
 import asyncio
 import json
 from typing import (
-    Callable, Coroutine, Dict, List, Optional, Type, Union, Any, Set, Tuple, cast
+    Callable, Coroutine, Dict, List, Optional, Type, Union, Any, Set
 )
 from pydantic import BaseModel
-from aio_pika.abc import AbstractIncomingMessage, ConsumerTag, AbstractRobustConnection
-from aio_pika import Channel, exceptions as aio_pika_exceptions
+from aio_pika.abc import AbstractIncomingMessage, ConsumerTag
 
 from sycommon.models.mqmsg_model import MQMsgModel
 from sycommon.models.mqlistener_config import RabbitMQListenerConfig
@@ -111,6 +110,8 @@ class RabbitMQService:
             if not hosts_list:
                 raise ValueError("RabbitMQ集群配置为空，请检查host参数")
 
+            global_prefetch_count = cls._config.get('prefetch_count', 2)
+
             # 创建连接池
             cls._connection_pool = RabbitMQConnectionPool(
                 hosts=hosts_list,
@@ -118,7 +119,8 @@ class RabbitMQService:
                 username=cls._config.get('username', ""),
                 password=cls._config.get('password', ""),
                 virtualhost=cls._config.get('virtual-host', "/"),
-                app_name=cls._config.get("APP_NAME", "")
+                app_name=cls._config.get("APP_NAME", ""),
+                prefetch_count=global_prefetch_count,
             )
 
             # 初始化连接池
@@ -174,7 +176,7 @@ class RabbitMQService:
                             f"监控客户端 '{client_name}' 连接状态失败: {str(e)}", exc_info=True)
 
                 # 检查连接池状态（如果连接池已关闭，重新初始化）
-                if not cls._connection_pool.is_alive:
+                if not await cls._connection_pool.is_alive:
                     logger.error("RabbitMQ连接池已关闭，尝试重新初始化")
                     asyncio.create_task(cls._init_connection_pool())
 
@@ -487,9 +489,11 @@ class RabbitMQService:
                 # 转换配置并强制设置create_if_not_exists为True
                 listener_dict = listener_config.model_dump()
                 listener_dict['create_if_not_exists'] = True
+                listener_dict['prefetch_count'] = listener_config.prefetch_count
                 queue_name = listener_dict['queue_name']
 
-                logger.info(f"设置监听器 {idx+1}/{len(listeners)}: {queue_name}")
+                logger.info(
+                    f"设置监听器 {idx+1}/{len(listeners)}: {queue_name} (prefetch_count: {listener_config.prefetch_count})")
 
                 # 添加监听器
                 await cls.add_listener(**listener_dict)
