@@ -97,7 +97,7 @@ async def feign(service_name, api_path, method='GET', params=None, headers=None,
                     data=data,
                     timeout=timeout
                 ) as response:
-                    return await _handle_feign_response(response)
+                    return await _handle_feign_response(response, service_name, api_path)
             else:
                 # 普通JSON请求
                 async with session.request(
@@ -108,21 +108,21 @@ async def feign(service_name, api_path, method='GET', params=None, headers=None,
                     json=body,
                     timeout=timeout
                 ) as response:
-                    return await _handle_feign_response(response)
+                    return await _handle_feign_response(response, service_name, api_path)
         except aiohttp.ClientError as e:
             SYLogger.error(
-                f"nacos:请求服务接口时出错ClientError path: {api_path} error:{e}")
+                f"nacos:请求服务接口时出错ClientError server: {service_name} path: {api_path} error:{e}")
             return None
     except Exception as e:
         import traceback
         SYLogger.error(
-            f"nacos:请求服务接口时出错 path: {api_path} error:{traceback.format_exc()}")
+            f"nacos:请求服务接口时出错 server: {service_name} path: {api_path} error:{traceback.format_exc()}")
         return None
     finally:
         await session.close()
 
 
-async def _handle_feign_response(response):
+async def _handle_feign_response(response, service_name: str, api_path: str):
     """
     处理Feign请求的响应，统一返回格式
     调整逻辑：先判断状态码，再处理内容
@@ -160,9 +160,9 @@ async def _handle_feign_response(response):
                     response_body = await response.text(encoding='utf-8', errors='ignore')
             except Exception:
                 binary_data = await response.read()
-                response_body = f"非200状态，响应无法解码：{binary_data[:100].hex()}"
+                response_body = f"非200状态，响应无法解码：{binary_data[:100].hex()} server: {service_name} path: {api_path}"
 
-            error_msg = f"请求失败，状态码: {status_code}，响应内容: {str(response_body)[:500]}"
+            error_msg = f"请求失败，状态码: {status_code}，响应内容: {str(response_body)[:500]} server: {service_name} path: {api_path}"
             SYLogger.error(error_msg)
             return {
                 "success": False,
@@ -174,5 +174,6 @@ async def _handle_feign_response(response):
     except Exception as e:
         import traceback
         error_detail = f"处理响应异常: {str(e)}\n{traceback.format_exc()}"
-        SYLogger.error(f"nacos:处理响应时出错: {error_detail}")
+        SYLogger.error(
+            f"nacos:处理响应时出错: {error_detail} server: {service_name} path: {api_path}")
         return None
